comments_client library

Legacy client API — use CommentsKit instead.

This file is deprecated and will be removed in a future release. Migrate to CommentsKit.initialize() + CommentsKit.I().

Classes

Comment
Immutable representation of a comment returned by the API.
CommentsClient
High level client that wraps the HTTP API exposed by the Comments backend.
CommentsExternalUser
Lightweight description of the end-user interacting with the comment UI.

Enums

CommentsUserRole
Roles supported by the Comments SaaS backend for authenticated users.

Exceptions / Errors

CommentsApiException
Exception thrown when the backend answers with an error payload.